@@ -18,8 +18,10 @@
 #
 # This translation was updated for Oddmuse 1.354.
 #
-$ModulesDescription .= '<p>$Id: bulgarian-utf8.pl,v 1.10 2007/08/19 11:42:07 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: bulgarian-utf8.pl,v 1.11 2009/06/07 19:30:37 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
+Include normal pages
+
 Reading not allowed: user, ip, or network is blocked.
 Не е разрешено четенето: блокиран потребител, IP адрес или мрежа.
 Login
@@ -70,8 +72,6 @@ CGI Internal error: %s
 
 Invalid action parameter %s
 Невалидна команда: %s
-Invalid URL.
-Невалидно URL.
 Page name is missing
 
 Page name is too long: %s
@@ -82,16 +82,14 @@ Invalid Page %s (must not end with .lck)
 Невалидна страница: %s (не може да завършва на .lck)
 Invalid Page %s
 Невалидна страница: %s
-Preview:
-Предварителен преглед:
-Preview only, not yet saved
-Предварителен преглед, още не е записано
+Too many redirections
+
+No redirection for old revisions
+
+Invalid link pattern for #REDIRECT
+
 Please go on to %s.
 Моля продължи на %s.
-All changes for %s
-
-No updates since %s
-Няма промени от %s насам
 Updates since %s
 Промени от %s насам
 Updates in the last %s days
@@ -144,10 +142,10 @@ rollback
 връщане на стара весия
 new
 
+All changes for %s
+
 from %s
 от %s
-: 
-
 This page is too big to send over RSS.
 
 History of %s
@@ -216,20 +214,24 @@ To mark a page for deletion, put <strong>%s</strong> on the first line.
 [Начална страница]
 redirected from %s
 Препратка от %s
+%s: 
+
 Click to search for references to this page
 Търси споменавания на това заглавие
 Cookie: 
 Курабийка (Cookie): 
+Edit this page
+Редакция на тази страница
+Preview:
+Предварителен преглед:
+Preview only, not yet saved
+Предварителен преглед, още не е записано
 Warning
 Предупреждение
 Database is stored in temporary directory %s
 Базатая данни се съхранява в %s
 %s seconds
 %s секунди
-The same page on other sites:
-Същата страница на други места:
-EditNearLinks
-Редакция на близки линкове
 Last edited
 Последна промяна
 Edited
@@ -240,8 +242,6 @@ by %s
 (разлики)
 Edit revision %s of this page
 Редакция на версия %s на тази страница
-Edit this page
-Редакция на тази страница
 e
 
 This page is read-only
@@ -404,22 +404,10 @@ Reason: %s.
 
 Reason unknown.
 
-Without normal pages
-
-Include normal pages
-
-Without permanent anchors
-
-Include permanent anchors
-
-Without near pages
-
-Include near pages
+Filter:
 
 (for %s)
 (за %s)
-Filter:
-
 %s pages found.
 %s намерени страници.
 Replaced: %s
@@ -428,16 +416,6 @@ Search for: %s
 Търси: %s
 View changes for these pages
 Промени на тези страници
-Search sites on the %s as well
-Също търси страници на %s
-and
-и
-or
-или
-Fetching results from %s:
-Набавям резултати от %s:
-Near pages:
-Близки страници:
 last updated
 последна промяна
 by
@@ -498,8 +476,6 @@ Note: This error is normal if no changes have been made.
 Забележка: Тази грешка е нормална, ако не са направени промени.
 Moving %s log entries.
 Преместване на %s лог-записа.
-Getting page index file for %s.
-Получаване на индекс за %s.
 Set or Remove global edit lock
 Налагане или отмяна на глобална защита от редакции.
 Edit lock created.
@@ -514,26 +490,16 @@ Lock for %s removed.
 Защитата за %s бе отменена.
 Displaying Wiki Version
 
-Show dependencies
+Debugging Information
 
 Inter links:
 Интер-линкове:
-Near links:
-Близки линкове:
-Show parsed link data
-
 Too many connections by %s
 Прекалено много връзки с %s
 Please do not fetch more than %1 pages in %2 seconds.
 
 Check whether the web server can create the directory %s and whether it can create files in it.
 
-anchor first defined here: %s
-Точката бе първо дефинирана тук: %s
-Click to search for references to this permanent anchor
-Кликни за търсене на връзки към тази постоянна точка
-the page %s also exists
-
 Copy one of the following stylesheets to %s:
 
 Deleting %s
@@ -572,6 +538,10 @@ Internal Page:
 
 Pages that link to this page
 
+The search parameter is missing.
+
+Pages link to %s
+
 Cannot highlight the language %s.
 
 Recent Visitors
@@ -688,8 +658,6 @@ ordinary changes
 
 Matching page names:
 
-Footnotes:
-
 Could not find %1.html template in %2
 
 Only Editors are allowed to see this hidden page.
@@ -706,6 +674,10 @@ Define
 
 Full Link List
 Пълен списък на линковете
+List of locked pages
+
+Pages tagged with %s
+
 Template without parameters
 
 The template %s is either empty or does not exist.
@@ -714,6 +686,8 @@ The template %s is either empty or does not exist.
 
 Local names defined on %1: %2
 
+Locked Pages
+
 Register for %s
 
 Please choose a username of the form "FirstLast" using your real name.
@@ -808,14 +782,74 @@ There was an error approving %s.
 
 There are no pending registrations.
 
+Invalid Mail %s: not saved.
+
+unsubscribe
+
+subscribe
+
+Email: 
+
+%s appears to be an invalid mail address
+
+Your mail subscriptions
+
+All mail subscriptions
+
+Subscriptions
+
+Show
+
+Subscriptions for %s:
+
+Unsubscribe
+
+There are no subscriptions for %s.
+
+Change email address
+
+Mail addresses are linked to unsubscription links.
+
+Subscribe to %s.
+
+Subscribe
+
+Subscribed %s to the following pages:
+
+The remaining pages do not exist.
+
+Unsubscribed %s from the following pages:
+
+You linked more than %s times to the same domain. It would seem that only a spammer would do this. Your edit is refused.
+
 %s is not a legal name for a namespace
 
+Namespaces
+
+Getting page index file for %s.
+Получаване на индекс за %s.
+Near links:
+Близки линкове:
+Search sites on the %s as well
+Също търси страници на %s
+Fetching results from %s:
+Набавям резултати от %s:
+Near pages:
+Близки страници:
+Include near pages
+
+EditNearLinks
+Редакция на близки линкове
+The same page on other sites:
+Същата страница на други места:
  (create locally)
 
 image
 
 download
 
+Backlinks
+
 Clearing Cache
 
 Done.
@@ -838,6 +872,20 @@ Self-ban by %s
 
 You have banned your own IP.
 
+OpenID Login
+
+Your identity is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
+
+Your homepage is set to %s.
+
+You have no homepage set.
+
+Homepage:
+
+Homepage is missing
+
+OpenID error %s
+
 Orphan List
 
 Trail: 
@@ -848,12 +896,20 @@ Type
 
 Permalink to "%s"
 
+anchor first defined here: %s
+Точката бе първо дефинирана тук: %s
+the page %s also exists
+
 There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.
 
 Someone else is generating a pdf for %s.  Please wait a minute and then try again.
 
 Download this page as PDF
 
+Click to search for references to this permanent anchor
+Кликни за търсене на връзки към тази постоянна точка
+Include permanent anchors
+
 Portrait
 
 Publish %s
@@ -864,10 +920,12 @@ The target wiki was misconfigured.
 
 You did not answer correctly.
 
-Use the back button to return the previous page and try again.
-
 To save this page you must answer this question:
 
+Please type the following two words:
+
+Please answer this captcha:
+
 Referrers
 Линкове
 All Referrers
@@ -884,6 +942,10 @@ Rebuilding index not done.
 
 (Rebuilding the index can only be done once every 12 hours.)
 
+New Pages for Indexed Search
+
+List changes since %s
+
  ... 
 
 Search term missing.
@@ -898,6 +960,8 @@ Tags: %s.
 
 No tags
 
+Page list for %s
+
 Slideshow:%s
 
 Index of all small pages
@@ -910,6 +974,14 @@ Copy to %1 succeeded: %2.
 
 Copy to %1 failed: %2.
 
+Feed for this tag
+
+Rebuild tag index
+
+list tags
+
+tag cloud
+
 Alternatively, use one of the following templates:
 
 Thread: %s
@@ -940,6 +1012,26 @@ Contents
 
 Create a new page for today
 
+Add Translation
+
+Added translation: %1 (%2)
+
+Translate %s
+
+Thank you for writing a translation of %s.
+
+Please indicate what language you will be using.
+
+Language is missing
+
+Suggested languages:
+
+Please indicate a page name for the translation of %s.
+
+More help may be available here: %s.
+
+Translated page: 
+
 This page is a translation of %s. 
 
 The translation is up to date.
