@@ -29,8 +29,9 @@
 
 #	Requires MultiMarkdown 2.0.a2 or higher
 
+#	TODO: auto links in codespans should not be interpreted  (e.g. `<http://somelink/>`)
 
-$ModulesDescription .= '<p>$Id: markdown.pl,v 1.37 2007/04/02 16:10:19 fletcherpenney Exp $</p>';
+$ModulesDescription .= '<p>$Id: markdown.pl,v 1.44 2007/09/12 05:02:13 fletcherpenney Exp $</p>';
 
 use vars qw!%MarkdownRuleOrder @MyMarkdownRules $MarkdownEnabled $SmartyPantsEnabled!;
 
@@ -45,7 +46,7 @@ $TempNoWikiWords = 0;
 
 sub MarkdownRule {
 	# Allow journal pages	
-	if (m/\G(\<journal(\s+(\d*))?(\s+"(.*)")?(\s+(reverse))?\>[ \t]*\n?)/cgi) {
+	if (m/\G(&lt;journal(\s+(\d*))?(\s+"(.*)")?(\s+(reverse))?\>[ \t]*\n?)/cgi) {
        # <journal 10 "regexp"> includes 10 pages matching regexp
         Clean(CloseHtmlEnvironments());
         Dirty($1);
@@ -133,11 +134,26 @@ sub MarkdownGetCluster {
 
 
 # Let Markdown handle special characters, rather than OddMuse
+
+# This opened up a security flaw whereby a user's input (e.g. search string)
+# would be displayed as raw HTML).
+#
+# It also appears that Alex has changed the way Oddmuse works, so I can't seem
+# to provide a workaround at this time. I don't remember why I had to add this
+# routine, so I am disabling it for now, and will have to "re-fix things" when
+# I figure out if anything is now broken....
+
+*oldQuoteHtml = *QuoteHtml;
 *QuoteHtml = *MarkdownQuoteHtml;
 
 sub MarkdownQuoteHtml {
 	my $html = shift;
 
+	$html =~ s/&/&amp;/g;
+	$html =~ s/</&lt;/g;
+#	$html =~ s/>/&gt;/g;
+	$html =~ s/[\x00-\x08\x0b\x0c\x0e-\x1f]/ /g; # legal xml: #x9 | #xA | #xD | [#x20-#xD7FF] | [#xE000-#xFFFD] | [#x10000-#x10FFFF]
+
 	return $html;
 }
 
@@ -192,7 +208,7 @@ sub DoWikiWords {
 		}{
 			my $label = $1;
 			$label =~ s{
-				([\s\>])($WikiWord)
+				([\s\&gt;])($WikiWord)
 			}{
 				$1 ."\\" . $2
 			}xsge;
@@ -232,7 +248,7 @@ sub DoWikiWords {
 	# WikiWords
 	if ($WikiLinks) {
 		$text =~ s{
-			([\s\>])($WikiWord)
+			([\s\&gt;])($WikiWord\b)
 		}{
 			$1 . CreateWikiLink($2)
 		}xsge;
@@ -355,8 +371,10 @@ sub NewDoHeaders {
 sub NewEncodeCode {
 	my $text = shift;
 	
-	# Undo sanitization of '<'
+	# Undo sanitization of '<, >, and &' (necessary due to a change in how Oddmuse works)
 	$text =~ s/&lt;/</g;
+#	$text =~ s/&gt;/>/g;
+	$text =~ s/&amp;/&/g;
 	
 	$text = OldEncodeCode($text);
 	
@@ -389,7 +407,8 @@ sub AntiSpam {
 sub NewDoAutoLinks {
 	my $text = shift;
 
-	$text =~ s{&lt;((https?|ftp|dict):[^'">\s]+)>}{<a href="$1">$1</a>}gi;
+	# Added > to the excluded characters list for Oddmuse compatibility
+	$text =~ s{&lt;((https?|ftp|dict):[^'"<>\s]+)\>}{<a href="$1">$1</a>}gi; 
 
 	# Email addresses: <address@domain.foo>
 	$text =~ s{
