@@ -1,8 +1,8 @@
-# Copyright (C) 2004, 2005, 2006  Alex Schroeder <alex@emacswiki.org>
+# Copyright (C) 2004, 2005, 2006, 2009  Alex Schroeder <alex@gnu.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -11,23 +11,36 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the
-#    Free Software Foundation, Inc.
-#    59 Temple Place, Suite 330
-#    Boston, MA 02111-1307 USA
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-$ModulesDescription .= '<p>$Id: markup.pl,v 1.31 2006/08/31 09:11:58 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: markup.pl,v 1.34 2009/03/13 22:28:29 as Exp $</p>';
 
-use vars qw(%MarkupPairs %MarkupSingles %MarkupLines $MarkupQuotes $MarkupQuoteTable);
+use vars qw(%MarkupPairs %MarkupForcedPairs %MarkupSingles %MarkupLines
+	    $MarkupQuotes $MarkupQuoteTable);
 
 $MarkupQuotes = 1;
-$MarkupQuoteTable = [["'", "'", '"', '"'], # 0
+
+# $MarkupQuotes	'hi'	"hi"	I'm	Favored in
+#	0	'hi'	"hi"	I'm	Typewriters
+#	1	‘hi’	“hi”	I’m	Britain and North America
+#	2	‹hi›	«hi»	I’m	France and Italy
+#	3	›hi‹	»hi«	I’m	Germany
+#	4	‚hi’	„hi”	I’m	Germany
+
+#                        0           1           2           3           4
+$MarkupQuoteTable = [[  "'",        "'",        '"',        '"'     ,   "'"     ], # 0
 		     ['&#x2018;', '&#x2019;', '&#x201d;', '&#x201c;', '&#x2019;'], # 1
 		     ['&#x2039;', '&#x203a;', '&#x00bb;', '&#x00ab;', '&#x2019;'], # 2
 		     ['&#x203a;', '&#x2039;', '&#x00ab;', '&#x00bb;', '&#x2019;'], # 3
 		     ['&#x201a;', '&#x2018;', '&#x201c;', '&#x201e;', '&#x2019;'], # 4
 		    ];
 
+# $MarkupQuoteTable->[2]->[0] ‹
+# $MarkupQuoteTable->[2]->[1] ›
+# $MarkupQuoteTable->[2]->[2] »
+# $MarkupQuoteTable->[2]->[3] «
+# $MarkupQuoteTable->[2]->[4] ’
+
 push(@MyRules, \&MarkupRule);
 # The ---- rule in usemod.pl conflicts with the --- rule
 $RuleOrder{\&MarkupRule} = 150;
@@ -86,6 +99,7 @@ sub MarkupInit {
 					       keys(%MarkupForcedPairs))) . ')';
   $markup_forced_pairs_re = qr/$markup_forced_pairs_re/;
   $markup_singles_re = '\G(' . join('|', (map { quotemeta(QuoteHtml($_)) }
+					  sort {$b cmp $a} # longer regex first
 					  keys(%MarkupSingles))) . ')';
   $markup_singles_re = qr/$markup_singles_re/;
   $markup_lines_re = '\G(' . join('|', (map { quotemeta(QuoteHtml($_)) }
@@ -155,23 +169,38 @@ sub MarkupRule {
     return '~/'; # fix ~/elisp/ example
   } elsif ($MarkupPairs{'/'} and m|\G(/[-A-Za-z0-9\x80-\xff/]+/$words/)|gc) {
     return $1; # fix /usr/share/lib/! example
-  } elsif ($MarkupQuotes and (m/\G(?<=[[:space:]])"/cg
-			      or pos == 0 and m/\G"/cg)) {
+  }
+  # "foo
+  elsif ($MarkupQuotes and (m/\G(?<=[[:space:]])"/cg
+			    or pos == 0 and m/\G"/cg)) {
     return $MarkupQuoteTable->[$MarkupQuotes]->[3];
-  } elsif ($MarkupQuotes and (m/\G"(?=[[:space:][:punct:]])/cg
+  }
+  # foo"
+  elsif ($MarkupQuotes and (m/\G"(?=[[:space:][:punct:]])/cg
 			      or m/\G"\z/cg)) {
     return $MarkupQuoteTable->[$MarkupQuotes]->[2];
-  } elsif ($MarkupQuotes and (m/\G(?<=[[:punct:]])"/cg)) {
+  }
+  # foo."
+  elsif ($MarkupQuotes and (m/\G(?<=[[:punct:]])"/cg)) {
     return $MarkupQuoteTable->[$MarkupQuotes]->[3];
-  } elsif ($MarkupQuotes and pos == 0 and m/\G'/cg) {
+  }
+  # single quotes at the beginning of the buffer
+  elsif ($MarkupQuotes and pos == 0 and m/\G'/cg) {
     return $MarkupQuoteTable->[$MarkupQuotes]->[0];
-  } elsif ($MarkupQuotes and (m/\G'(?=[[:space:][:punct:]])/cg
-			      or m/\G'\z/cg)) {
+  }
+  # 'foo
+  elsif ($MarkupQuotes and (m/\G(?<=[[:space:]])'/cg
+			    or pos == 0 and m/\G'/cg)) {
+    return $MarkupQuoteTable->[$MarkupQuotes]->[0];
+  }
+  # foo'
+  elsif ($MarkupQuotes and (m/\G'(?=[[:space:][:punct:]])/cg
+			    or m/\G'\z/cg)) {
     return $MarkupQuoteTable->[$MarkupQuotes]->[1];
-  } elsif ($MarkupQuotes and m/\G(?<![[:space:][:punct:]])'/cg) {
+  }
+  # foo's
+  elsif ($MarkupQuotes and m/\G(?<![[:space:]])'(?![[:space:][:punct:]])/cg) {
     return $MarkupQuoteTable->[$MarkupQuotes]->[4];
-  } elsif ($MarkupQuotes and m/\G(?<=[[:space:][:punct:]])'/cg) {
-    return $MarkupQuoteTable->[$MarkupQuotes]->[0];
   }
   return undef;
 }
